summaryrefslogtreecommitdiffstats
path: root/src/driver/svg.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/driver/svg.php')
-rw-r--r--src/driver/svg.php21
1 files changed, 14 insertions, 7 deletions
diff --git a/src/driver/svg.php b/src/driver/svg.php
index 54e9689..55c0ad5 100644
--- a/src/driver/svg.php
+++ b/src/driver/svg.php
@@ -15,6 +15,12 @@
class ezcGraphSVGDriver extends ezcGraphDriver
{
+
+ public function __construct( array $options = array() )
+ {
+
+ }
+
/**
* Draws a single polygon
*
@@ -75,15 +81,16 @@ class ezcGraphSVGDriver extends ezcGraphDriver
/**
* Draws a circular arc
*
* @param ezcGraphCoordinate $center
* @param mixed $width
* @param mixed $height
* @param mixed $startAngle
* @param mixed $endAngle
* @param ezcGraphColor $color
* @return void
*/
- public function drawCircularArc( ezcGraphCoordinate $center, $width, $height, $startAngle, $endAngle, ezcGraphColor $color )
+ public function drawCircularArc( ezcGraphCoordinate $center, $width, $height, $size, $startAngle, $endAngle, ezcGraphColor $color )
{
}
OpenPOWER on IntegriCloud
@@ -75,15 +81,16 @@ class ezcGraphSVGDriver extends ezcGraphDriver
* Draws a circular arc
*
- * @param ezcGraphCoordinate $center
- * @param mixed $width
- * @param mixed $height
- * @param mixed $startAngle
- * @param mixed $endAngle
- * @param ezcGraphColor $color
+ * @param ezcGraphCoordinate $center Center of ellipse
+ * @param integer $width Width of ellipse
+ * @param integer $height Height of ellipse
+ * @param integer $size Height of border
+ * @param float $startAngle Starting angle of circle sector
+ * @param float $endAngle Ending angle of circle sector
+ * @param ezcGraphColor $color Color of Border
* @return void
*/